==> qtjambi-xml-debuginfo-linux-x64-6.7.1.jar: sources/QtJambiXml/QDomNodeList_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtXml/qdom.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiXml/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDomNodeList(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDomNodeList")
    QDomNodeList *_ptr = reinterpret_cast<QDomNodeList *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDomNodeList()
void __qt_construct_QDomNodeList(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomNodeList()")
    Q_UNUSED(__java_arguments)
    QDomNodeList *__qt_this = new(__qtjambi_ptr) QDomNodeList();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QDomNodeList::QDomNodeList()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomNodeList_initialize_1native__Lio_qt_xml_QDomNodeList_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomNodeList::QDomNodeList()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomNodeList, sizeof(QDomNodeList), typeid(QDomNodeList), 0, false, &deleter_QDomNodeList, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDomNodeList(QDomNodeList)
void __qt_construct_QDomNodeList_cref_QDomNodeList(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomNodeList(QDomNodeList)")
    jobject arg__1 = __java_arguments[0].l;
    const QDomNodeList& __qt_arg__1 = qtjambi_cast<const QDomNodeList&>(__jni_env, arg__1);
    QDomNodeList *__qt_this = new(__qtjambi_ptr) QDomNodeList(__qt_arg__1);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QDomNodeList::QDomNodeList(QDomNodeList)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomNodeList_initialize_1native__Lio_qt_xml_QDomNodeList_2Lio_qt_xml_QDomNodeList_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomNodeList::QDomNodeList(QDomNodeList)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomNodeList_cref_QDomNodeList, sizeof(QDomNodeList), typeid(QDomNodeList), 0, false, &deleter_QDomNodeList, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDomNodeList
void __qt_destruct_QDomNodeList(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDomNodeList")
    reinterpret_cast<QDomNodeList*>(ptr)->~QDomNodeList();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDomNodeList::at(int)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomNodeList_at_1native_1int_1constfct__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint index0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDomNodeList *__qt_this = QtJambiAPI::objectFromNativeId<QDomNodeList>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomNodeList::at(int)const", __this_nativeId)
        QDomNode __qt_return_value = __qt_this->at(static_cast<int>(index0));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomNodeList::count()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomNodeList_count_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QDomNodeList *__qt_this = QtJambiAPI::objectFromNativeId<QDomNodeList>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomNodeList::count()const", __this_nativeId)
        __java_return_value = __qt_this->count();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomNodeList::isEmpty()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomNodeList_isEmpty_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QDomNodeList *__qt_this = QtJambiAPI::objectFromNativeId<QDomNodeList>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomNodeList::isEmpty()const", __this_nativeId)
        __java_return_value = __qt_this->isEmpty();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomNodeList::item(int)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomNodeList_item_1native_1int_1constfct__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint index0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDomNodeList *__qt_this = QtJambiAPI::objectFromNativeId<QDomNodeList>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomNodeList::item(int)const", __this_nativeId)
        QDomNode __qt_return_value = __qt_this->item(static_cast<int>(index0));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomNodeList::length()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomNodeList_length_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QDomNodeList *__qt_this = QtJambiAPI::objectFromNativeId<QDomNodeList>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomNodeList::length()const", __this_nativeId)
        __java_return_value = __qt_this->length();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomNodeList::operator=(QDomNodeList)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomNodeList_assign_1native_1cref_1QDomNodeList__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomNodeList *__qt_this = QtJambiAPI::objectFromNativeId<QDomNodeList>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomNodeList::operator=(QDomNodeList)", __this_nativeId)
        const QDomNodeList& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QDomNodeList>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomNodeList::operator==(QDomNodeList)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomNodeList_equals_1native_1cref_1QDomNodeList_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QDomNodeList *__qt_this = QtJambiAPI::objectFromNativeId<QDomNodeList>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomNodeList::operator==(QDomNodeList)const", __this_nativeId)
        const QDomNodeList& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QDomNodeList>(arg__1);
        __java_return_value = (*__qt_this) == __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomNodeList::size()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomNodeList_size_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QDomNodeList *__qt_this = QtJambiAPI::objectFromNativeId<QDomNodeList>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomNodeList::size()const", __this_nativeId)
        __java_return_value = __qt_this->size();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomNodeList_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QDomNodeList *__qt_this = QtJambiAPI::objectFromNativeId<QDomNodeList>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomNodeList_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDomNodeList *__qt_this = QtJambiAPI::objectFromNativeId<QDomNodeList>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDomNodeList(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QDomNodeList>("QDomNodeList", "io/qt/xml/QDomNodeList");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QDomNodeList, {
        ConstructorInfo(&__qt_construct_QDomNodeList, nullptr)
       ,ConstructorInfo(&__qt_construct_QDomNodeList_cref_QDomNodeList, "Lio/qt/xml/QDomNodeList;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDomNodeList);
    registerMetaType<QDomNodeList>("QDomNodeList");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-xml-debuginfo-linux-x64-6.8.3.jar: sources/QtJambiXml/QDomNodeList_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtXml/qdom.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiXml/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDomNodeList(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDomNodeList")
    QDomNodeList *_ptr = reinterpret_cast<QDomNodeList *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDomNodeList()
void __qt_construct_QDomNodeList(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomNodeList()")
    Q_UNUSED(__java_arguments)
    QDomNodeList *__qt_this = new(__qtjambi_ptr) QDomNodeList();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QDomNodeList::QDomNodeList()
extern "C" JNIEXPORT void JNICALL Java_io_qt_xml_QDomNodeList_initialize_1native__Lio_qt_xml_QDomNodeList_2
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomNodeList::QDomNodeList()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomNodeList, sizeof(QDomNodeList), typeid(QDomNodeList), 0, false, &deleter_QDomNodeList, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDomNodeList(QDomNodeList)
void __qt_construct_QDomNodeList_cref_QDomNodeList(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomNodeList(QDomNodeList)")
    jobject nodeList0 = __java_arguments[0].l;
    const QDomNodeList& __qt_nodeList0 = qtjambi_cast<const QDomNodeList&>(__jni_env, nodeList0);
    QDomNodeList *__qt_this = new(__qtjambi_ptr) QDomNodeList(__qt_nodeList0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QDomNodeList::QDomNodeList(QDomNodeList)
extern "C" JNIEXPORT void JNICALL Java_io_qt_xml_QDomNodeList_initialize_1native__Lio_qt_xml_QDomNodeList_2Lio_qt_xml_QDomNodeList_2
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject nodeList0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomNodeList::QDomNodeList(QDomNodeList)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = nodeList0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomNodeList_cref_QDomNodeList, sizeof(QDomNodeList), typeid(QDomNodeList), 0, false, &deleter_QDomNodeList, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDomNodeList
void __qt_destruct_QDomNodeList(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDomNodeList")
    reinterpret_cast<QDomNodeList*>(ptr)->~QDomNodeList();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDomNodeList::at(int)const
extern "C" JNIEXPORT jobject JNICALL Java_io_qt_xml_QDomNodeList_at_1native_1int_1constfct__JI
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint index0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDomNodeList *__qt_this = QtJambiAPI::objectFromNativeId<QDomNodeList>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomNodeList::at(int)const", __this_nativeId)
        QDomNode __qt_return_value = __qt_this->at(static_cast<int>(index0));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomNodeList::count()const
extern "C" JNIEXPORT jint JNICALL Java_io_qt_xml_QDomNodeList_count_1native_1constfct__J
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QDomNodeList *__qt_this = QtJambiAPI::objectFromNativeId<QDomNodeList>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomNodeList::count()const", __this_nativeId)
        __java_return_value = __qt_this->count();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomNodeList::isEmpty()const
extern "C" JNIEXPORT jboolean JNICALL Java_io_qt_xml_QDomNodeList_isEmpty_1native_1constfct__J
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QDomNodeList *__qt_this = QtJambiAPI::objectFromNativeId<QDomNodeList>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomNodeList::isEmpty()const", __this_nativeId)
        __java_return_value = __qt_this->isEmpty();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomNodeList::item(int)const
extern "C" JNIEXPORT jobject JNICALL Java_io_qt_xml_QDomNodeList_item_1native_1int_1constfct__JI
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint index0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDomNodeList *__qt_this = QtJambiAPI::objectFromNativeId<QDomNodeList>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomNodeList::item(int)const", __this_nativeId)
        QDomNode __qt_return_value = __qt_this->item(static_cast<int>(index0));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomNodeList::length()const
extern "C" JNIEXPORT jint JNICALL Java_io_qt_xml_QDomNodeList_length_1native_1constfct__J
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QDomNodeList *__qt_this = QtJambiAPI::objectFromNativeId<QDomNodeList>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomNodeList::length()const", __this_nativeId)
        __java_return_value = __qt_this->length();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomNodeList::operator=(QDomNodeList)
extern "C" JNIEXPORT void JNICALL Java_io_qt_xml_QDomNodeList_assign_1native_1cref_1QDomNodeList__JJ
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomNodeList *__qt_this = QtJambiAPI::objectFromNativeId<QDomNodeList>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomNodeList::operator=(QDomNodeList)", __this_nativeId)
        const QDomNodeList& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QDomNodeList>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomNodeList::operator==(QDomNodeList)const
extern "C" JNIEXPORT jboolean JNICALL Java_io_qt_xml_QDomNodeList_equals_1native_1cref_1QDomNodeList_1constfct__JJ
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QDomNodeList *__qt_this = QtJambiAPI::objectFromNativeId<QDomNodeList>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomNodeList::operator==(QDomNodeList)const", __this_nativeId)
        const QDomNodeList& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QDomNodeList>(other0);
        __java_return_value = (*__qt_this) == __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomNodeList::size()const
extern "C" JNIEXPORT jint JNICALL Java_io_qt_xml_QDomNodeList_size_1native_1constfct__J
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QDomNodeList *__qt_this = QtJambiAPI::objectFromNativeId<QDomNodeList>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomNodeList::size()const", __this_nativeId)
        __java_return_value = __qt_this->size();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" JNIEXPORT jint JNICALL Java_io_qt_xml_QDomNodeList_hashCode_1native
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QDomNodeList *__qt_this = QtJambiAPI::objectFromNativeId<QDomNodeList>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" JNIEXPORT jobject JNICALL Java_io_qt_xml_QDomNodeList_clone_1native
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDomNodeList *__qt_this = QtJambiAPI::objectFromNativeId<QDomNodeList>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDomNodeList(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QDomNodeList>("QDomNodeList", "io/qt/xml/QDomNodeList");
    Q_UNUSED(typeId)
    registerConstructorInfos(typeId, 0, &__qt_destruct_QDomNodeList, {
        ConstructorInfo{&__qt_construct_QDomNodeList, nullptr}
       ,ConstructorInfo{&__qt_construct_QDomNodeList_cref_QDomNodeList, "Lio/qt/xml/QDomNodeList;"}
    });
    registerDeleter(typeId, &deleter_QDomNodeList);
    registerMetaType<QDomNodeList>("QDomNodeList");
}
